2022-02-25

# 3.85 GOST 17216 Support

This is a significant update adding full support for the GOST 17216:2001 reporting format
("GOST").

Currently we support size ranges as follows
```
1-2um
2-5um
5-10um
10-25um
25-50um
50-100um
100-200um
```
The 0.5-1.0um range is not supported. NB the standard does not require 0.5-1.0um
for purity classes above 0, and does not require 1.0-2.0um counts for classes
above 1.

Since we calibrate using MTD and optical particle counters measure um(c), we
convert to the "equivalent" um(c) values.
```
1um == 4.2um(c)
2um == 4.6um(c)
5um == 6.4um(c)
10um == 9.8um(c)
25um == 21um(c)
50um == 38um(c)
100um == 70um(c)
```
Values up to 10um are taken from the table in the SRM2806 certificates. Values
above this are taken from those in e.g. AS4059 that use both size definitions.

We count at 4um(c), 6um(c), 14um(c), 21um(c), 25um(c), 38um(c), 50um(c), 70um(c).

Cumulative counts for the GOST um(c) equivalent sizes are found using interpolation
from those at the above um(c) calibration points.

The differential GOST counts are then found by subtraction in the usual way.

### Points for Discusion

- should possibly remove the 1-2um size range, not clear if this will be a good
  approximation to the equivalent microscopy results. E.g. MTD has less particles
  in the "1-2um" range than the "2-5um" range, if the 4.2 and 4.6um(c) 
  "equivalents" are used.
- we treat GOST sizes slightly differently from e.g. NAS. For GOST we interpolate
  to the precise equivalent decimal MTD size but for NAS we use integer rounded size values.
  E.g. 4um(c) instead of 4.6um(c) and 6um(c) instead of 6.4um(c). There is an
  argument we should do this for NAS and AS4059 table 1 also.
- the standard is unclear about some things
  - How are counts above the tabulated range to be represented (e.g. "*")
  - The top size range is 100-200um rather than >100um which implies >200um particles
    should be ignored. In any case we are unable to do this so we are in fact using >100um.
  - The standard gives a formula for converting particle counts to total contaminant mass
    and then assigning a purity class based on the mass. This seems redundant since
    we already have the table to assign class based on the counts directly.
  - *It should be noted that even the standard itself recommends simply using ISO4406
    instead of all this!*


### Detailed Changes

- added GOST 17216 to reporting format chooser dialog
- add 7-column bar chart graph for GOST
- add 7-channel differential counts table for GOST sizes
- Implement GOST limits setting screen. Overall class and codes
  for individual size ranges similar to NAS
- colorisation of counts and classes and codes according to set limits
- add GOST format to history. GOST limits are stored along with each
  test result and colorisation done according to the stored values not
  the current settings in the case where these are different (allowing
  different settings for different machines / customers).
- printouts: add GOST reporting format, GOST size ranges, GOST
  differential counts, GOST purity class

## Windows Simulator

The windows simulator has been enhanced so as to demonstrate and test
some of these functions. New results are now updated on-screen and added
to the simulated log. The simulation range is chosen to excercise the
GOST display over the full possible range of the standard (class 0 to >17)
accross all size channels.

This may affect use by sales team however if they are used to previous
behaviour.

### Windows Simulator Appearance

- Added a "skin" to simulator; there is now a wide black surround so as to
  look like the LPA3 screen


## LPA3 Firmware Simulator

The simulated test mode built into the firmware is similarly adjusted
so as to excercise the full GOST range.


## Other Changes

- fix bug that forced continuous test sample volume to 100ml since 3.80


2021-11-10

3.84

# Fix Flush in Simulation

Simulations for online test mode would activate the flush valve. This is now
fixed.

## PC Simulator Time Fixed

The simulated date and time are now initialised by the PC's own values
so will be initially accurate instead of being from 2019 etc.

Also the simulated passage of time is close to 1 second per second.
Before it was too fast so the seconds display looked strange on the
date & time setting page.

## Updated Graphics Framework to 4.18

NB format of translations spreadsheet has changed.




2021-11-04

3.83

- changed text for bottle sampling warnings

2021-10-11

3.82

- fix simulated bottle sample mode homing loop

- changed "no manual flush for bottle samples" warning to only show once
  per session (i.e. do not show repeatedly, just once after being switched on)

- Any manual override of bottle sample volume is cleared when re-enter screen
  or when starting a new test.

- bottle sample volume manual override disabled for 200, 500ml sizes

2021-10-05

3.81

- fix screen background remaining "live" to touch when bottle
  sampling check list wizard being displayed.

- added popup to home screen when screen entered and in bottle sample
  mode. About "no manual flush when bottle sample mode selected"

- greyed out flush button when in bottle sample mode

- added another popup if user tries to flush manually in bottle sample mode

- fix windows simulator display of required volumes for bottle sampling

- changed simulator to show countdown on splash screen, shows all the
  warning levels as simulated date approaches cal due

2021-07-27

3.80

- fix time set and calibration required updates from LPA-View.
  Broken since 3.74.

- Experimental Bottle sample warning / checklist / wizard

- Add option for user to enter volume of media directly. Flush is always
  30ml, with sample volume preset to use all media.

- update framework to 4.17

2021-01-25

3.78

2021-06-14

# Adjust Bottle Sample and Bottle Sample Flush Volumes, Again

- now 40ml and 30ml respectively

# Adjust Bottle Sample and Bottle Sample Flush Volumes 

- now 50ml and 20ml respectively

# Countdown Timer on Splash Screen, Calibration Warnings Etc




2021-01-21


3.77

# Fix Bottle Sample Fluid Volume Settings Screen Bug

Bottle sampling sample volume was being preset to 50ml every time settings
screen was entered. This behaviour is now fixed.



2021-01-12

3.76

# Bottle sample mode- settings screen

- Added test explanation to settings screen as per start button
- Added display of fluid requirement as per bottle test confirmation dialog



2021-01-11

3.75

# Bottle Sample Warning

Add confirmation dialog for bottle sample test with display of fluid
required for chosen test.


2020-12-15

3.74

# Manual Time, Date and Timezone Setting

A new dialog has been added to manually set the timezone, date and time.
Previously this could only be done via LPA-View setting screen.

The timezone should be set first, as per on-screen warning, since this
changes the displayed local time setting.


### Battery Bug Fix

Up until now, due to a bug, setting the time using LPA-View would
lock the non-volatile memory of the LPA3, until the next power cycle.
This would e.g. prevent the battery capacity from being updated after
a full charge / discharge.


2020-11-23

3.73

# New bottle sampling modes to use automatic pumped flush

Test types renamed to

 - ONLINE
 - ONLINE - CONTINUOUS
 - BOTTLE

Bottle size selection for bottle sampling test mode (100,200,500 ml)

Bottle sampling test reworked to use an automatic pumped flush instead of
a manual timed one.

Selecting the bottle size results in the following behaviour:

- "100ml" - 25ml pumped flush followed by 60ml sample
- "200ml" - 25ml pumped flush, empty then 100ml sample.
- "500ml" - 25ml pumped flush, empty then 100ml sample. Option for extra
  automatic 100ml "verification" test. (Tickbox option that appears
  when 500ml bottle size is chosen).

## Other changes

- Printout of flush setting shows seconds or ml appropriately
- Start button explanation updated to show flush, sample, #tests
- "Sub test number" added to internal log and USB stick data log. Can
  add to LPA-View at some point.

# Printouts in Selected Language

Printouts are now in the currently selected language.

The language can be changed and the result re-printed in the new
language.

All languages translated except CN. Hopefully this will be enough for now.
The current printer model does not directly support CN or other non-western
fonts. It would still be possible to do it in principle using a graphics
printing mode but that would be a lot of work to implement.
It would also make the printout speed significantly slower.

2020-10-05

3.72

## Allow down to zero flush time in continuous test mode

Simplified "Universal" Test Cycle is:

- FLUSH for flush time, if not bottle sampling, enforce minimum 30s
- SAMPLE
- EMPTY - with flushing if wait time is 0
- WAIT for wait time, unless 0
 - FLUSH during WAIT for flush time, if set
- goto SAMPLE above if still in continuous test sequence

The previous behaviour was that it would always flush during empty for the
continuous test mode. This is now disabled if a wait time has been programmed.
We flush towards the end of the wait time instead, unless the flush time has
been set to zero.

The rationale is that setting a wait time indicates the user will be concerned
about wasting fluid. E.g. the fluid is not being returned to tank - since 
otherwise there is not much reason to program a wait time. They can program
a flush time which will occur just before the end of the wait time, just before
the next sample is taken. The purpose of a flush is to ensure that the fluid in 
the sampling hose is representative of the system sample about to be taken. When
there is a wait time programmed, fluid drawn by the flush during empty will
only be representative of the previous cycle and will be discarded anyway.

The above behaviour with respect to flush during empty should be reviewed
to see if it is what we want.

# Fix flush valve operation in simulated test

- fix spurious flush valve operating during simulation mode in 
  continuous test when wait time enabled

3.71

## Printer Option

- Printer option can now be disabled in LPA-View system settings
- This requires LPA-View 5.103+
- Existing LPA3 with previous firmwares will have the new option defaulted
  to "on".
- turning the option off will hide the "print" icon on the main and history
  screens. It will also hide the "print settings" icon on the settings
  screen.

3.70

## BUBBLE MITIGATION

Bubble mitigation processing of counts -  In any real-life particle size
distribution there will be many more small particles than large ones. For
example each AS4059F size range code requires 4-6 times as many particles
than the next size up, for the same code value.

We wish to prevent e.g. single bubbles in a clean system from producing 
results like 8/8/8 or NAS 9 (0/0/0/0/9)

## Bubble Mitigation Enabled

We require a differential count to be less than the differential count of
the next size range down. That is, working backwards from the largest size
range (70+), if 38_70 count is less than the 70+ count, suppress the 70+
count. Then if the 21_38 count is less than the 38_70 count, suppress the
38_70 AND the 70+ counts. Etc.

To "suppress" the count we set the offending count, and the counts of the
sizes above, to approximate a "typical" distribution extrapolated from the
count of the preceding channel. This falls of rapidly with particle size.
Since these issues usually occur in clean systems these will be very low
counts in any case.

Presently this is an experimental option that can be activated using
the latest dev version of LPA-View in LPA3 system settings.

2020-09-23

# 3.69 Fix AS4059x Table 1 showing wrong sizes

The AS4059 Table 1 formats were showing "um" sizes (5,15,25 etc) instead
of "um(c)" sizes (6,14,21 etc). The AS4059 standards mandate use of um(c)
exclusively where an automatic particle counter is used.

This is now fixed. Changes are for the AS4059E&F table 1 and GJB420.

- counts printout
- home & history screens:
 - detailed counts:
  - size column title
  - size column sizes
 - graph:
  - sizes
  - size axis title

2020-07-14

# 3.68 Remove "SIMULATION" warning on PC simulator

Removed from main screen

So can do screenshots more easily for documentation.

2020-06-25

# 3.67 -T mode

This uses the temperature sensor built into the pressure transducer to measure 
temperature. Instead of the not-fitted RH sensor.

Requires LPA-View >= 5.96 to enable in system settings and also to 
process the result correctly within lpa-view.

Once factory enabled in system settings the RH sensor function is not available.
Temperature is then measured at the end of the test and logged etc with
an "empty" RH measurement. I.e. RH is "null" and should not appear
anywhere.

There is no user-level setting to turn this on/off.


2020-02-18

# 3.66 Reduce flow rate for bottle sampling mode.

Flow rate for bottle sampling has been reduced to 20ml/min
in order to allow thick fluids to be pumped correctly.

2020-01-27

# 3.65 Remove Flush time from start button for Bottle Sampling

## Remove Flush time from start button for Bottle Sampling.

Previously it still showed a flush time even though bottle sampling
mode uses manual flush.

## Minimum Flush Time Reverted to 30s

The minimum flush time has been changed back to 30s.

Slider can set 30, 60,120 seconds.

user can also program between 30 and 3600 seconds.

2020-01-21

# 3.64 Flush Time, Fix Pressure Transducer Scaling

## New limits and defaults for Flush Time

Minimum flush time now 60s.
Slider defaults are 60,90,120s.

## Fix Pressure Transducer Scaling

Previously the displayed reading would have been 20% low.

2019-11-18

# 3.63 Fix Flush Activation in Simulation Mode

## Fix Flush Activation in Simulation Mode

Up until now the manual flush button could still be used to activate the
flush valve even in "simulation" mode.

This has now been changed so that the valve does operate even if
the manual flush button is pressed.

## Minimum Sample Volume

The minimum sample volume that can be entered has been increased from 10ml to 25ml.
The slider values remain at 25, 50 and 100ml.
Previously a manually entered sample volume less than 10ml was forced to 10ml.
Now the value 25ml is used for any value entered below 25ml.


2019-11-16

# 3.62 Battery Charging Bug Fix, Fonts, New Framework Version

## Battery Charging Bug Fix

The root cause of the battery display issues has been located.

Details for reference:

There has been a long standing bug where the display of the unit state of charge
has sometimes been inconsistent. A typical symptom of this is triggered by running
a unit on battery until it runs out of charge completely, then plugging in the charger.

Occasionally when this is done the displayed charge jumps straight to the "fully charged"
state. When in reality the battery is still hardly charged at all. If the charger is
then unplugged after only a few minutes (because it falsely indicates fully charged),
the LPA3 will then not last long on battery power.

Also if this is done the apparent capacity of the battery will be reduced 
to a small capacity, so the unit may appear to charge and discharge very quickly
in future unless it sees a genuine full charge by being left plugged in. (Or 
until the battery parameters are reset from the diagnostic screen).

The root cause of the bug is that a completely discharged battery is handled
specially by the charging hardware, in order not to damage it. It initially
charges at a low current until a minimum voltage is seen.

This confused the software which sees a low charge current, so it thought the 
battery was fully charged and sets the charge indicator accordingly.

This behaviour is now fixed. Existing units in the field may have erroneous
battery parameters. These should self-correct over time (by seeing the fully
charged and fully discharged states). Or the parameters can be manually
reset from diagnostics mode.


## Fonts

Reworked fonts to use freely distributable versions. Some changes may be
visible. The fonts are now a combination of "Noto Sans CJK Regular" and
"Liberation Sans Regular". Please use the texts.xls from this version
as a base for any further translation work.

## Upgraded Graphics Framework

This should be transparent to users but please report any oddities.

2019-10-10

# 3.60 FR translations, correct limits screen size displays

Sizes were missing/corrupted for FR and CN due to texts spreadsheet
errors.


2019-11-12

# DO NOT USE 3.61 Battery Charging Bug Fix, Fonts, New Framework Version

This version does not work correctly - not released


2019-10-08

# 3.59 DE tranlations


# 3.58 Translations, Simulation Warning

Incorporated new translations for DE, FR, IT, CN.
These will need checking.

Added "SIMULATION" to start button when simulating.


2019-07-17

# 3.57 Increase maximum pump drive

This is to try to maintain closed loop control of the pump motor when
the new gearbox is fitted.

2019-06-07

# 3.56 Fix Autocalibration Thresholds

This fixes the autocalibration system threshold setting phase. Previously
incorrect values would be written and the verification tests would fail.



2019-06-06

# 3.55 Fix Sample Volume 120ml

This fixes a bug where the set sample volume is changed to 120ml each
time the unit starts sampling. This bug is present since 3.52.

2019-05-30

# 3.54 Fix Timezone Handling

Requires one-off connection from LPA-View >= 5.81

Added timezone offset setting. This is a hidden setting, set automatically 
when unit is connected to LPA-View >= 5.81.

This new timezone offset fixes the following issues observable when local
time is different from GMT/UTC.

- history view title incorrect timestamp shown
- history view scrolling list incorrect timestamps
- lp2 / csv file on USB stick incorrect timestamps
- printout incorrect timestamps
- lp2 lpa-view file import incorrect timestamps

2019-05-29

# 3.53 WIP logging fault debug

- tests now logged even in diagnostics mode so any problems are picked
  up during calibration / testing at MP
- reworked driver for logging memory

2019-05-18

# 3.52 Further Autocalibration Support

The test cycle has been modified to allow accumulating a result over
multiple pump cycles. This should allow a more repeatable calibration
to be performed. The number of cycles is determined by lpa-view.
Intermediate results are visible after each pump cycle but these are
based on counts and volumes which are accumulated as the lpa-view
calibration cycle is performed.

##Other Changes

- limit pump stroke if user sets too high sample volume from lpa-view


2019-05-16

# 3.51 Autocalibration Support, bug fixes, cleanups

- improve remote device status display when running from LPA-View
  (correctly show Emptying, Waiting, Flushing etc). Ideally requires LPA-View
  5.78+

- fix corrupted target flow rate when viewed in lpa-view system settings

- Added LPA3 status codes for Low Pressure and RH sensor fault display

## Add New Auto-calibration Support

- measure sampling and emptying pump currents and make available to lpa-view
- add pump emptying target flow
- new test cycle for automatic noise measurement
- new setting to allow separate sampling and emptying flow rate settings

2019-05-02

# 3.50 Help Screen Lockup Bug Fix

This release contains a change intended to fix the lockup bug observed that
seems related to accessing the help screen.

2019-04-15

# 3.49 Settings Screen Reporting Format Display Bug Fix

This fixes a bug where the reporting format was always initially displayed
as ISO4406, regardless of the actual value in use. This is a cosmetic bug
in that the correct set value is what is used for the test. And the main
screen equivalent settings behaves normally also.

This bug is now fixed.


2019-04-15

# 3.48 Various fixups for Release units

## Continuous test mode - flush during wait behaviour

Previously the unit flushed for the full emptying time + waiting time before
starting the next test. This can waste a lot of fluid in the case where the
fluid is not returned to tank.

It is desired to limit flushing to the set pre-test flush time value. Or to
30s if the set value is less than this.

- extra flush is only needed in the case of a programmed (non-zero) wait time.
  Since the purpose is to ensure all of the fluid sample is "up to date" with 
  the system condition.

- if set flush time is greater than set wait time, we do not need to extend the
  wait time due to purpose of flush time above. The set flush time will just
  be used before the test.

## Help Screen / Button

Replaced content with text from user guide 6.1.1.

NOTE: this screen now requires translation again.

## GOST

Removed GOST from list of reporting formats since we do not support it yet

## IT, DE translations

Added IT and DE translations. Some fixup needed for excessively long text items.

## PT language

Deleted the PT language since we have no translations for it

## Serial Number display

Added serial number to firmware version line on settings screen

## Diagnostic Screen Clear Battery Parameters

After confirmation, the auto-tuned battery parameters are cleared (battery capacity,
state of charge, charging efficiency). This may be needed after changing the
battery or if these parameters are corrupted. The battery gauge will not
be accurate until the unit sees an almost discharged battery and an almost
fully charged battery (in any order).

## Diagnostic Screen Clear Cycle Counter

After confirmation, the cumulative cycle counter is cleared. This should not be
needed except in case of corruption of the count e.g. failure of the PCB
coin cell.

## Diagnostic Screen use Water Sensor

Tickbox added to enable this hardware option. If the option becomes disabled then
the "Measure RH" test option will also be disabled and the icons removed
from the main and settings screen etc.

2019-03-25

Work to support LPA3 online calibration WIP

- make noise measurement work again on diagnostics screen

Noise threshold measurement - seems to be left up to manufacturer 
but "minimum voltage setting of an automatic particle counter at 
which the observed pulse-counting frequency does not exceed 60 counts/min
due to electrical noise in the absence of flow in the sensing volume"

Ideally would obtain a histogram over a period and establish a threshold
at which 60 per minute is obtained.

## Limit sample volume to 100ml

Maximum sample volume is now limited to 100ml as requested.

2019-03-15

# 3.47 "Stop when clean" / "after N confirmations" functions added

As per recent request...

The continuous test cycle has been extended with extra functions.
We already had a "repeat n" function where the continuous test sequence
would be terminated after a set number of tests.

There is now a new tickbox "Stop When Clean". When enabled, the "repeat n"
setting is hidden and a new setting "confirm N times" becomes available.
The unit will then perform continuous tests until N tests pass consecutively.
If no limits are in force then this is the same as all tests being "clean".
So the unit will stop after N tests.

"Clean" requires all result codes and classes to not exceed any set 
associated warning (lower) limit.

The limits screen shortcut has been placed next to the "stop when clean"
tickbox to remind users to set / check the limits to be used.

## Erase Log Button on History Screen

This has been removed to reduce the risk of accident (although there was
already a confirmation dialog). The button on the Settings screen remains.




2019-03-14

# 3.46 Keyboard auto-repeat

This has now been implemented. "Holding down" a key for more than 300ms
will result in the key "auto-repeating" every 150ms. Support for auto-repeat
has also been added in the PC simulator, it can be seen by holding down the
left mouse button over a key on the on-screen keyboard.

As a side effect of this change, the key now "operates" its function as
soon as it is touched. Previously it operated the function upon release.

2019-03-14

# 3.45 Custom wait time + various cosmetic improvements

## Simulation Mode warning

The main screen now shows a "SIMULATION" warning top right if the 
LPA3 is in a simulation mode. (Either from being enabled on the
unit, or if running the PC simulator). Touching the warning text
turns off simulation mode (it can also be turned off in the settings
screen as before).


## Hide RH and Temperature limits if hardware option not enabled

This is now implemented

## RH & Temperature in Simulation Mode

Simulation should not log rh&temp if option not fitted or if turned
off in settings. This is now implemented. Previously the LPA3 would
show a simulated RH and Temperature even when these were switched off.

## History updated when change between degrees F and C

Previously history list remained in old format until updated by
something else (screen change or new result).

## Custom wait time button

The continuous test wait time slider now has a "..." button next to it that
allows a "custom" wait time to be entered, up to 3600 seconds.

2019-03-13

# 3.44 RH Disabled and Service Mode Fixes

## RH Fitted System Option

Made a disabled RH system option work properly. If disabled in 
system options, the water content test option is now forced off and
it is then not shown on the settings screen.

## "Service Mode"

Logging is now disabled when diagnostics mode is enabled, akin to LPA2
"Service Mode". LPA-View will still log the tests if run "online" which
could be useful. Previously testing at MP would contaminate the log as
far as the customer was concerned.


2019-03-13

# 3.43 Code Colouring in History

Rewrite of log history facility to allow this to be coloured correctly as
per live results. In particular the ISO code is shown with appropriate
colours for each code component if limits are set for these.

Removed "History screen" button from the sidebar. This is because it
seemed redundant. The "history screen" is now entered by touching one
of the entries on the history list on the main screen. Previously
if the button was used then no entry was highlighted so there was
nothing to display in the area for test details.

Enforce maximum and minimum set limit for RH and temperature.

Temperature: -25 to 100'C
RH: 0 to 100 %RH

## Bugs

Fix degrees F limit setting bug. Previously were unable to set limit if in
degrees F; degrees F value set was entered as degrees C value.

Fix display of RH limit 100, previously text was truncated on each side.

## Simulator

Be aware that the simulator is limited and cannot show the entire operation
of the user interface at this point. It is able to show the detailed
colouring of the log and the result, counts and graphs.






2019-03-05

# 3.42 Code Colouring

This is a big update concerning the colouring of both classes and individual
size channels according to the set limits.

This is a WIP / preview.

We have individual colouring of the graph channels according to the result
class and/or individual codes.

The overall contamination result is coloured also but not by individual code.

Colouring of the overall result is switched on by setting a limit on the
limits screen.

Colouring of an individual size channel can be switched on by setting an
individual size limit.

## Contamination Limits - Discussion

The various reporting formats are not compatible in general, although many
may share features.

So there is a problem with the concept of "limit" with respect to switching
between reporting formats. Limits for one format cannot in general be
*accurately* converted into limits in another format. For example ISO
limit 22/19/15 has no exact NAS equivalent.

Investigation of the detailed definitions of all the reporting formats
reveals that there are 3 basic "types", or likely 4 if we include GOST
(which we have not implemented yet).

So we therefore now have 4 distinct sets of upper and lower limits for
expressing contamination limits. The limits screen now displays the set
appropriate for the set reporting format. Most users can ignore all of
this by just using the reporting format for their industry. They will
just see the one set of limits.

NB the LPA2 also has separate limits for each type of reporting format
although the ICM does not.

The "types" of reporting format are:

1) ISO4406/GBT14039: "ISO4406-like"
2) NAS1638/AS4059E+F Table 1: "NAS1638-like, differential" 
3) AS4059E+F Table 2 / cumulative
4) GOST

The current settings for all limits are stored with each individual log
result. The allows the log to be coloured according to the limits in
force at the time of the test. The reason for this was in case the
user wanted to set different limits for different machines, for example.

*New LPA-View Required* for log download (probably). Needs lpa-view >= 5.77.

In-memory log format changed. May be issues with old logs, can erase log
if so. Old log entries will not have set limits stored correctly so
e.g. may be shown as red all the time. The new format stores the set limits
along with each log entry so that a recalled result can be coloured according
to the limits in force at the time rather than the current limit settings.


2019-02-21

# 3.41 Enhanced PC Simulator

This release enhances the PC simulator so that the start and flush
buttons "work".

- Flush button can be pressed and changes state to show "Manual Flush" /
  "Flushing" as per real machine.
- Start button can be pressed and goes through a "test cycle" with the
  button changing state and showing the progress indicator.

2019-02-20

# 3.40 Error / Fault Reporting

This release adds a mechanism to allow tracing of program faults that
happen in the field.

Previously the unit would simply freeze, either just the screen or
else the whole system.

- the unit should no longer "freeze", it should instead now reboot. This
  is important since a lockup at the wrong point could damage the pump 
  mechanism. Also users may not be aware of the "long-press" hard 
  power-off method of resetting the unit.
- a fault message is written to non-volatile memory to allow subsequent
  investigation. This should allow the cause to be pinpointed. Previously
  this was very difficult when it could not be reliably reproduced.
- after reboot the message pops up in a dialog on the main screen with
  a suggestion to report the exact message.
- after the user dismisses the dialog the message will be erased and
  normal operation will resume.

2019-02-18

# 3.39 - Added FR and CN languages

This release includes initial support for the CN and FR translations.

- some items are not translated yet because they were not included in
  the translation spreadsheet. Doing this is WIP.

- the limits screen is not translated because it was developed after
  the FR and CN translations were first done.

- Some of the fonts have been changed so as to include the required
  characters (i.e. the CN).

- a few translations are too verbose to fit. We will need to find a
  shorter translation, or reduce the font size, or increase the space
  allocated for the text. NB the same font size must be used for all
  translations of a given item.

2019-02-12

# 3.38 Limits

##Limits Screen

Added a new "limits" screen used to enter the upper and lower limits
for contamination codes, RH and Temperature. This is similar in function
to the equivalent part of the ICM settings screen in LPA-View. While the
LPA3 has no "alarm" relay outputs, the limits will be used to colour-code
test results, similar in concept to the ICM screen changing colour.

The current reporting format is also shown on this screen. Touching the
format brings up the reporting format chooser as per other screens.

Similarly touching the Temperature icon allows selection of degrees C
 or F. For temperature the set limit is automatically converted to and
from the chosen format. E.g. a 100 degrees C upper limit changes to a 212
degrees F one if the format is changed from degrees C to degrees F.

No such conversion is possible between e.g. an ISO code limit and a NAS
code limit so these need to be entered specifically for the desired
format. Having said that there is no change needed when changing 
between similar formats, broadly they are mostly all "NAS based" or
"ISO based". It is expected that a given user will tend to only use 
the reporting format used in their industry sector.

# Colouring of Results

## Main Result Area Result Colouring

Added initial support for colouring the results based on their values
compared to the set limits (if any).

The RH, temperature and contamination class results are coloured
green, yellow or red according to the set limits.

- Above the upper limit is red. 
- Otherwise, above the lower limit is yellow.
- Otherwise, the result is green.

The detailed codes are now left white since we are not individually
colorizing these yet (previously were yellow which is now misleading).

## History List Colourisation

The history list is coloured in a similar way to the main result.
However an important point is that historical results are coloured
according to the *test limits in force at the time of the original test*.

# Bug Fixes

Several bugs fixed relating to consistency of Deg F / C switching with main
screen and history.

##Simulator

In the simulator the results will currently all show green since there are no
programmed limits by default. However the new limits screen is functional.











# Simulator

Fixed Simulator history screen so recalls "recorded" temperatures,
 RH, pressures for display.

Fixed simulator standby screen so can go back into main screen instead
of being stuck after you press the simulated power button. (The real
unit will power-down in any case unless charging).




2019-02-04

# 3.37 Log Recall & History Screen

Implemented log recall function and a working history browser screen.

Tapping a test record in the history list now "loads" that record onto
the screen. The history screen now appears as a near-duplicate of the
main screen, so that it can show most of the test record details in 
a familiar way:

 - test reference
 - reporting format (not part of record, this is the system-wide setting)
 - class
 - detailed code
 - detailed counts / graph area
 - RH
 - temperature
 - pressure

There is a large HISTORY title to ensure the user knows they are looking
at old results. Pressing this goes back to the "live" result as does the
home screen icon.
 
The pressure switch state is not shown since a test will not complete
in any case if not active. So there will be no test records with a 
low pressure state recorded.

The START button has been replicated on the history screen, since it
seems useful to know the live state of the system while examining
history during testing. Also it acts as an "emergency stop" if e.g. a
waste bottle is overflowing. We should probably have the button on all 
screens at some point. On the other hand the FLUSH button is not 
present.

The reporting format can be changed to allow the history to be viewed
in formats other than that in force when a test was done.

Similarly the Temperature and Pressure units can be changed to view
the history in the desired units.

## RH & Temperature Simulation

The simulated values of RH, temperature and pressure now change slightly
with each simulated test

## Print Button

The print button has been moved from the sidebar on to the Home and History
screens. This is because it now has different functions depending on 
the screen. On the main screen it prints the live test result.
On the history screen it prints the recalled test result.

## Erase Log

Made Erase Log button into icon and put one on the settings screen. Not
sure if we really need this at all - may be more trouble than it is worth.
Can always erase the log from LPA-View.

## UNCALIBRATED Indication

Units that have never been calibrated now show "UNCALIBRATED" instead of
"next calibration 2038-XX-XX"


# 3.36 Adjust Behavior in case of RH sensor failure

Previously a failed RH sensor could prevent the particle count from
being logged since the whole test was then invalidated.

Also if the RH sensor failed during operation then a previously
measured value would be used.

Now if the RH sensor fails then the test can proceed as normal except
that the RH and temperature values are blank. This is for failures
either at power-up or during operation.

For intermittent failures (e.g. the sensor intermittently shorting 
on the sensor block body) then if the failure is present at power-up
the unit will not be able to measure a value until the unit is 
power-cycled (with the fault cleared). This is because the calibration
coefficients are read at power-up only.

If the fault is not present at power up, occurs later and then vanishes,
the unit should recover by itself and start producing readings for tests
the are done with the sensor working (around the end of sampling).


# 3.35 # Initial Support for 4000 records

This release adds support for a larger memory chip that can hold 4000
test records vs the 1000 previously allowed. The chip fitted is auto
detected so there is no configuration. Boards with the new chip require
this firmware or later in order to use the extra memory. Installing
earlier firmware should work but with only 1k records available.


# Misc

Shrunk the flags graphic to be less obtrusive

working close button on language chooser dialog



2019-01-24

# 3.34 Preliminary Multi-Language Support

Added Language button to settings screen. This brings up a language
chooser dialog. Choosing a language closes the dialog and redraws
the screen in the chosen language. I translated the "Wait" slider into
the 6 supported languages to test the function.

The chosen language is shown as a two-letter code on the button
"EN", "FR" etc.


2019-01-23

# 3.33 Settings Screen Flicker Bug Fix

Versions from ~3.29 have a bug the causes flickering controls on the settings
screen. This is activated by switching from continuous to bottle sampling
mode. Touching the sample volume slider then causes the previously
displayed continuous test mode setting sliders to flicker into visibility.
This could be fixed by re-entering the screen by e.g. pressing the settings icon
on the side bar.

This is now fixed.


2019-01-22

# 3.32 Reworked printout

- adjusted font sizes and placement
- added sample volume, flush time, pressure reading
- rearranged printout items


2019-01-22

# 3.31 Larger main screen pressure display

fix diagnostic screen crash on PC simulator

larger icons and font for pressure display control on main screen


2019-01-21

# 3.30 bug fix for locked up UI during empty

This would have been present since 3.23 (only).

A bug meant that the screen locked up half way through emptying, under certain
circumstances.

- the lockup would only ever happen every 8 tests
- the bug was also temperature sensitive, e.g. it only happened on some units
  when above a certain temperature.

This "lockup during emptying" bug should now be fixed. An effort was made to
remove any potential similar bugs at the same time.

## Test Reference
Fixed potential bugs concerning test reference when set to 32 characters.
NB test reference is a maximum of 31 characters. Previous versions allowed
32 characters to be set, this was incorrect and caused some issues if attempted.
Attempts to set longer texts are now truncated at 31 characters, whether
done from the LPA3 keyboard or remotely (lpa-view).


2019-01-11

# 3.29 Continuous test repeat N function, bottle sampling warning

Implement repeat_n in the actual test cycle. Previously setting existed
but did nothing.

for bottle sampling mode we disable the flush time setting box and show
a warning about sample volume vs bottle size


2019-08-01

# 3.28 Added PC simulator DLLs to Distribution

The DLL files required to run the simulator are now included in the
distribution (i.e. the released ZIP file).

To run the simulator, allow windows to extract all the files when
prompted, after e.g. double-clicking the lpa3-simulator.exe
file within the zip. Or manually extract all files so they are in the
same folder as the lpa3-simulator.exe file.

"regular testers" can copy the DLLs into c:\windows\system32 in which
case you can run lpa3-simulator.exe directly from within the zip without
the extraction step. This was the previous technique.


2019-01-01

# 3.27 Updated Graphics Library to 4.10




2018-12-26

# 3.26 Pressure Switch Integrated with Pressure Transducer Icon

We now have an "integrated" indicator for the system pressure. This is
a gauge icon at main screen bottom left. It has tick/cross emblems for the
pressure switch state and a digital display for the pressure transducer.
These elements are all optional depending on which of the pressure transducer
and the pressure switch have been fitted / enabled.

When the switch is fitted, the icon has a red cross emblem when the pressure
is too low to perform a test. When there is sufficient pressure, the
pressure switch is activated and the cross changes to a tick. This is a
"live" icon, in that the cross/tick reflects the instantaneous state of
the switch. It does not wait for start or end of test etc. If there is a 
momentary pressure drop such that the switch goes off briefly, then the
icon will show a momentary change from a tick to a cross in line with the
switch state.

The possible options are then as follows:

No transducer and no switch: No pressure displays at all.

Transducer Only: Displays a gauge icon with digital display of bar/psi value.
No tick or cross emblem. A low pressure *will not* prevent test start or
cause any test abort.

Switch Only: Displays gauge and a tick/cross for switch state. A low pressure
*will* prevent test start or abort a test in progress.

Transducer + switch: Displays gauge icon, tick/cross emblem representing switch
state, and digital pressure value in bar/psi.  A low pressure *will* prevent
test start or abort a test in progress.

2018-12-24

# 3.25 Battery State of Charge (SOC) Model Fixes

Bug fix: After battery low voltage cutout, restoring power sometimes
sets charge to 100% immediately. Apparent capacity then increases as the
battery charges from this incorrect value. This leads to an unrealistically
high apparent battery capacity.

The battery monitoring algorithm has been rewritten to be more reliable in
this and several other respects.

Some notes for reference, on how the system works.

The battery is a nominal 6000mAh capacity when new. This varies with age,
usage cycles, temperature, discharge current, and ones definition of the
"fully charged" and "fully discharged" endpoints.

The system measures the battery charge and discharge current in order to 
track the state of charge (SOC). This is the number of mAh of charge
in the battery at a given moment. This is the "Charge" indicated on
the diagnostic screen.

The system also attempts to track the actual capacity of the battery, i.e.
the 6000mAh value above is adjusted in the long term to track the
degradation of the battery over time. This should allow failing batteries
to be identified at service, and allow good batteries to remain in service
instead of throwing them away. This capacity is shown on the diagnostics
screen and the combination of charge and capacity is used to drive the
battery gauge. E.g. charge = 3000mAh, capacity = 6000mAh, gauge shows 50%
when charging. The 3000mAh is converted to an equivalent run-time when
discharging, using an averaged value of the systems current consumption.

A new PCB is assigned parameters of 6000mAh for capacity and 3000mAh for
the state of charge (since this is unknown). As the unit is operated,
charged and discharged the battery current is accurately measured. The
SOC is incremented or decremented each second by this current value so
the system maintains an estimate of the charge in the battery at a given
moment. Changes in capacity and errors in the charge model are corrected
at the endpoints of the battery operation, i.e. at the fully charged and
nearly discharged conditions. Since these can be detected directly
from the voltage and current values: Fully charged is when the charge
current falls near zero. Nearly discharged is when the battery voltage
falls below 11.5V (at which point there is only about 2% of life left).

If the battery parameters appear incorrect the system can be fully charged
then allowed to run until the battery cuts out. This will allow the parameters
to be accurately tuned. This does take a long time so if preferred the
unit can just be operated normally until the parameters become corrected.
I.e. until the algorithm as seen both the fully charged and nearly 
discharged states as part of normal operation.



## Pressure Switch Support

All units are supposed to ship with a pressure switch fitted. This is
supposed to ensure there is a minimum pressure available suitable for
sampling. Up until now this has been ignored.

We have a new setting on the diagnostic screen to enable it (in case it
has not been fitted to some of the pre-production units).

If enabled in the system options, the switch acts as follows:

If a START is attempted with low pressure, the start button changes to
show "LOW PRESSURE" in red. The user must press it to acknowledge,
then it turns back into the normal green "START".

Low pressure is then allowed during the auto flush part of the cycle
(in case the higher flow causes an excessive pressure drop for viscous
fluids). However during the sampling phase a low pressure signal will
cause the test to be aborted and go into the "LOW PRESSURE" state
described above.

FOR DISCUSSION: 
  - we could disallow auto flush at low pressure.
  - we could prevent manual flush at low pressure.
  - when the inlet hose is disconnected, with pump and flush off, 
    can there be a residual pressure that can still trip the switch?


2018-12-20
# 3.24 "Erase Log" button, enhanced battery gauge

## Erase Log Button

Added button to history screen so that user can erase the log. There is a 
confirmation dialog. The erasure takes ~5 seconds so the screen will be
unresponsive during this time.

## Battery Gauge
The battery gauge has been updated so as to show an estimate of the remaining
battery run time. I.e., the amount of time the unit can be powered before
recharging is needed. When charging the display reverts to the charge %
as before.

The "time remaining" is estimated from the battery state of charge and
the measured battery current drain. The current drain is averaged over
about 10 minutes to reduce fluctuations in the displayed "time remaining".
However this filter is bypassed if the user adjusts the brightness, so
that the effect on displayed time left is immediate in this case. This is
so an operator can immediately see the effect on battery life of changing
the brightness (which can be substantial).

It is impossible for the system to predict future usage so the time 
remaining displayed value may show unexpected changes on occasion.
For example if the unit does continuous tests for ~10 minutes, the
predicted time remaining will be based on this continuing indefinitely.
The gauge will show a relatively short time remaining. If the tests are
then stopped, over a ~10minute period the gauge will change to show a
longer time. If instead of waiting 10 minutes the brightness is adjusted,
the time remaining value will immediately jump to reflect the "not testing"
current drain.

The "time left" is heavily "rounded" so it is not fluctuating all the time.

- For >5h it just shows the number of hours
- 1+ hours it shows hours and minutes rounded to 10 minutes
- 20+ minutes it shows minutes rounded to 5 minutes
- else it shows the number of minutes



2018-12-17
# 3.23 History View

We now have a scrollable "history" list. This shows the test result log
in a list format. It can be scrolled by touch. Each entry shows:

- timestamp in form YYYY-MM-DD HH:MM:SS (based on ISO8601 format)
- Test Reference
- RH and Temperature (if these were originally measured, else omitted).
- Contamination code / class

The contamination code is shown in the currently selected format.
This can be different from that selected when the test was performed.
This means that a test can be done in NAS1638 and then later viewed
 as ISO4406 for example (if desired). The codes are dynamically
recalculated from the stored particle counts.

Similarly the temperature is displayed in the currently chosen units
(degrees C or degrees F). So a temperature measured in F can be later
shown in C if desired.

Presently the list shows the most recent 100 log entries.

At the moment the list appears on the main screen and also on the
"history" screen.


2018-12-03
# 3.22 Bar Graphs

Graphs
======

This release adds a bar chart graphical representation of the test result.

Bar graphs are working for all formats and simply show each part of a singular 
tests result code as the height of the bar.

The "Line" graphs (size distribution curves) are also still available for
the formats where these make sense. These are ISO4406 and GBT14039.

The user can swap between a counts table and the graphs by touching them.

Rationale
---------

As before the particle size distribution curve is only available for the two 
ISO4406-based reporting formats.

This is because singular result codes in other formats cannot be easily 
interpreted when presented as a continuous curve (line). Codes for these
other formats are based on a more arbitrary allocation of counts to codes.

It would be possible to allow line graphs of the particle counts themselves
however this again seems problematic in the case of the standards based
on differential counts. Because then there is no concept of the count
"between" two adjacent size bins. E.g. there is no point between 5-15
and 15-25. Wheres the curve value midway between the 4um(c) and 6um(c)
values does have meaning; it approximates the count for 5um(c) particles.


# 3.21 "First Touch" bug-fix, USB file timestamps

USB Stick File Timestamps
--------------------------

Previously these were empty so that no modification date appeared in e.g.
Windows Explorer. These are now correctly timestamped using the time and
date in the real time clock.

## Bug Fix: not working first touch
For all releases, there is a bug where the first operator touch is ignored.
(Unless you wait for >10s in which case it is seen normally!).

This is now fixed, the first touch is seen normally.

2018-11-27
3.20 Cal due, cycle counter etc
===============================



Pump Cycle Counter
------------------

Added a persistent pump cycle count as requested.
This appears on the diagnostics page. It is kept in "battery backed RAM" i.e.
memory that is maintained by the coin cell on the PCB. It can survive a 
coin cell change provided the new one is fitted within 1 minute or so.


Calibration Due
---------------

The system checks the calibration due date, set automatically after a calibration. 
The date is set upon the first use after the calibration date, after an initial
2 week period.

Starting 60 days before the cal due date, the due date appears in the settings 
screen title bar in black. After the cal due date has passed, then the date
turns red. The simulator has been adjusted to show this scenario.

The cal due date is also shown in the setting screen title bar.

*We will need to decide if this needs to be refined and in what way exactly.
Also whether any further notifications are required and what these should be.*


Firmware Revision
-----------------
The short version is now shown in the Settings screen (e.g. 3.19).


---

## 3.19 Power management, boot time, bootloader installer.

2018-11-23

Bootloader Installer
====================

We now have a separate firmware installer for the "bootloader". This is a small,
critical piece of code that runs at power-up before the main application. It is
separate so that if a main application code update fails, it does not leave the
LPA3 in a state where it can never be reprogrammed. (This is the same as the ICM
and many other products although not the LPA2 which could be "bricked" fairly
easily). The bootloaders purpose is to load firmware updates when needed (i.e.
when the windows firmware update utility is running). It also performs some
early initialisation of the hardware.

A failure during update of the bootloader itself *can* brick the device,
so bootloader updates should not be done unless needed. Bootloader updates will
be relatively rare, there is no need to apply just because one is included 
in the firmware release zip file.

The release includes a modified bootloader to improve boot time, and the
installer for it. If instead the previous bootloader is used with this 3.19+, 
users will likely see a screen flash at power-up (but this is only a cosmetic
defect).


Boot Time
=========

Optimised the boot process to make it ~3 times faster. This was to improve
the perceived behavior of the power button. Boot up is now effectively "instant".
Together with the fix to the spurious standby screen described below this should
remove confusion over the button operation and system state.

Part of this fix required a new bootloader, this is a separate firmware update
as described above.


Power management, power on/off behavior
========================================

When on battery, power button now correctly turns on / off instead of going
via standby screen. NB standby screen is not a low power mode it should only
be on when actually charging. You should not have to hold in power button ever
except for two situations:
1) you want to load new firmware when also plugged into mains. In this case
    holding in the button is the only way to force a reboot/reload.
2) the firmware has crashed/locked up and the screen is not responding in 
    which case the power button will likely not respond either unless held in.

Also while playing with all this, be aware that if you keep turning it on and off
quickly then the analog circuitry that measures the button pressed time gets
confused. The "hard off" press time can then be reduced to the point where it
does a hard power down with a shorter press than usual. This is harmless in itself
and may not be noticeable any more with the fixes.

To recap the intended behavior, for reference:

With no adapter connected
-------------------------
Short press of mechanical power button switches between fully-off and fully on.
The on-screen button can also be used to switch the unit fully off. Of course it
cannot be used to switch the unit on since it will not exist at that point.
The standby screen is not "off", it will use a similar amount of power as usual
but that should not matter since it is only supposed to come on when the adapter
is plugged in (when it then does not use any battery power at all).

If the firmware has crashed then a long press can force a power-down (when neither
a short press or the screen will work).

With Adapter Connected
----------------------
The unit always has to be active when the adapter is connected so it can manage
the charging process and in particular track the battery charge value.
  
- Plugging in the adapter should put an "off" unit into the standby screen.
- Unplugging it when in standby should cause a power-down.
- Pressing the mechanical or on-screen power button should cause the unit to
  toggle between the standby screen and the splash/main screen.




---

2018-11-13

## 3.18 Data Download Bug Fixes, removed triple test

There is an LPA-View release associated with these changes

Data Download
--------------

This release fixes some bugs with data download for the LPA3 (online 
download using LPA-View, not the USB stick).

- previously, erasing the log caused a lock-up requiring a reset.
- depending on the number of records, if the number was a multiple of 8
  then log download would terminate early with only e.g. "1 record downloaded".

These bugs should now be fixed.

"Triple" Test Removed
---------------------

The "triple/bottle sample" test is now just "bottle sampling". 
References to "triple" have been removed everywhere. All tests are now just
"single" tests.

The bottle sampling test type no longer selects a triple test mode
for the counts table. The on-screen counts table is single-only as is
the printout.





2018-11-05

## 3.17 Data Download Change

Data Download
-------------

Data download has been modified in an incompatible way with previous versions.
Now Requires LPA-View >= 5.75.






2018-10-29

## 3.16 Calibration Bug Fix

Calibration
-----------

This release should fix a bug that prevented online calibration.




2018-10-26

## 3.15 - USB Flash Drive

USB Stick
---------

The USB flash drive is now working. 

The behavior is similar to the ICM, the log is automatically written
once when the USB stick is inserted into the USB connector.
The entire log is saved as <serial number>.lp2 and any existing file of that 
name is silently overwritten.

Compared to the ICM, the system now works with the FATEx filesystem as well as
the FAT32 previously supported.

We have a notification icon in the "button bar" area. This shows the state of
the USB flash drive (plugged in, writing file, success/failure) using various
graphical elements.

In Detail: the USB stick icon comes on when the stick is plugged in. The arrow
icon pointing into the stick icon comes on when the LPA3 tries to write out the
log file to the stick. If this succeeds there is an overlaid green tick emblem.
If it fails there is an overlaid red cross emblem. These stay until the USB 
stick is removed, at which point all the USB icons vanish.

The USB stick needs to be pre-formatted (using the FAT32 or FAT32Ex filesystems,
normal for Windows machines and most devices).

Misc Cosmetic Adjustments
-------------------------

Grayed out buttons on settings screen that are for not implemented functions.

Changed "printer settings" button to an icon.

As experiment changed title bar colours.

- history screen has original "washed out yellow" colour. This is the yellow/orange
used in the MP logo on the UK website. It has been made partially transparent.

- Settings screen has the same but opaque

- diagnostics screen has "MP Blue" from the same logo.

Take your pick or can use another colour or no colour etc.




2018-10-18

## 3.14 - Sample, Flush Sliders. Diagnostic Mode. Splash Screen, Keyboard Prompts.


Sample Volume: Predefined and User Programmable
-----------------------------------------------

This release experiments with using sliders for entry of sample volume and flush
time. The project plan specifies both a set of "standard" volumes (e.g. 25,50,100 ml)
and "user programmable" options. Here we have a slider to choose 25, 50 or 100 and
a "..." button next to it to allow numerical entry of a custom value. NB we could
have different constraints on the slider values, e.g. 10,20,30,40,50,60,70,80,90,100ml
instead of 25,50,100. User programmable values are forced to be within the range
10-120ml.

Flush Time
----------

This is similar except there is a larger range of times that might be wanted. For now
we use 30, 60, 120 seconds. As with the flush volume, arbitrary user values can be
programmed. The range for these is 0 to 3600 seconds. (0 = no auto flush).

Graph / Counts
--------------
Made graph / counts selection persistent (i.e. a setting). Previously it would
switch back to graph display at power up or screen change.

Diagnostics Mode
----------------
Started proper implementation of a "diagnostics mode" for the LPA3. Currently we have
a new icon on the settings screen that switches diagnostics mode on and off. Turning
on requires entry of a password (currently the same as the LPA2).

When on, we disable the splash screen and enable the diagnostics screen icon
on the side menu / icon bar.


Splash Screen
-------------
The splash screen now appears at startup when not in diagnostics mode.

Keyboard
--------
Add keyboard prompt function to keyboard. The keyboard now displays a "prompt"
line at the top to explain the setting being changed.

Icons
-----
Added a couple of icons to the Setting screen for Water measurement and Diagnostics.
These now have tick and cross "emblems" to indicate enabled or disabled. (We could
then omit the text potentially but left in for now).


 

## 3.13 - Keyboard


Keyboard
--------

Reworked the keyboard.

- memory usage much reduced (not user visible except for reduced programming time)
- Moved towards the "transparent icons" look.
- Replaced "OK" and "CANCEL" with tick and cross icons respectively
- Keyboard background is now the "carbon fibre" texture.

Backlight Slider
----------------

Minor tweak to new backlight slider to add transparency to "filled" state.


## 3.12 Backlight Slider, Icon Refresh

Backlight Control - now implemented as a slider as per suggestion. Also designed
a new nicer icon for it.

Power button now has a green "backlight" when the LPA3 is "on" (not in standby).

Moved print icon into "icon bar" since there is space for it at the moment.

Battery % - somewhere along the way we lost the % sign on the battery icon. This
is now restored.

2019-10-15

## 3.11 Graph, Simulator, Icons WIP

Graph
-----

This release contains a new graph feature for the main screen count details
area. It only works for ISO4406 and GBT14039 (which are the same essentially).
For these coding formats, the detailed counts display area can be switched
between showing the detailed counts table and showing a graphical representation.
This is done by tapping the counts/graph area.

The graph is updated automatically as new results are generated.

As per the project plan, this graph expresses the size distribution of a 
single test result graphically. I.e. it is not a "trend graph".

The graph is a cumulative distribution plot of the particle size, using a number
scale as per ISO4406.

The sizes (4,6,14 etc) are spaced using a logarithmic scale. Otherwise a linear
scale will tend to have the 4,6 and 14 sizes bunched up on the far left and the graph
appears dominated by the larger sizes. Which is the opposite of what most users will
be interested in.

The graph format is a line plot. A bar graph format is possible also if wanted.

PC Simulator
------------

Some work has been started to improve the PC simulator program. 

- Changing reporting format now maintains consistent codes and graphs etc instead of
  nonsense.
- The settings are preset to more sensible values, including the test reference which
  is no longer empty at startup


Icons
-----

The background has been removed from most of the "button" icons, as an experiment.
Let me know which is preferred. We can color them as well etc if desired. They are
in a minimal style which seems to be the modern approach but they can be anything
really. They are just images (with transparency at present so the background shows
through).


Notes

- I looked at making the PC simulator appear to go through a test sequence but it is
not so easy so have deferred for now.





2019-10-09

## 3.10 - Printer Support

This release adds a fairly comprehensive printing function.

As part of this the logging and data transfer functions have been altered and
are now WIP.

The printout supports the usual items, currently
  timestamp
  id
  test number
  reference
  test type
  reporting format
  class
  codes
  detailed counts
  rh & temperature
  space for notes

It obeys all the options in "printer options" and supports all the test formats.
There are titles and layout for the triple tests but no actual stage counts yet
since these are not implemented for the testing either.

There is a printer icon on the main screen to command a print manually. There
is also the auto-print result printer option.

The layout and font sizes etc can be adjusted in future releases if needed.

After power-up there is no "live" test record so the printer will not work.
After a test there is then a test record which can be printed.

The printout is a combination of underlying recorded results, and more "cosmetic"
presentational options. While the underlying result cannot be changed without
doing another test, the presentation can be changed as desired by the operator
and the printout redone with the new presentation.

That is, it is possible to change some items after the fact to change what is printed.
The same underlying test results are used but are presented differently. These items are
  - reporting format
  - degrees F / degrees C change
  - turn on/off printer options
    - detailed counts
    - print test reference
    - add space for notes

So the user can fiddle with these options and repeat the printout until they
get the presentation they want.

Other items of course form a permanent part of the test record and cannot be modified 
without performing a new test. Such as
  - serial number (as far as user is concerned)
  - test type
  - test reference
  - test number
  - timestamp
  - cumulative counts upon which codes and differential counts are based
  - rh & temperature readings


2018-10-03

## 3.9 GJB420B, USA units

- enabled GJB420 B reporting format since "this is AS4059E2". Was already
  enabled on the LPA-View side.

- Implemented temperature display in degrees F option. Touch the display to
  change between degrees C and degrees F.

- Implemented pressure display in PSI. Touch the display to switch between
  PSI and Bar. Reduced update rate since looks a bit jittery on psi otherwise.


2018-10-02

## 3.8 - "clickable" main screen items

- Test Reference: clicking the test reference line allows editing the reference

- reporting format: clicking the reporting format brings up the reporting format
  chooser dialog. As a result of this the separate reporting format button
  seems redundant so has been removed.

- Test sequence: The test sequence (normal, continuous, triple) can be set
  from the main screen. Click the description above the start button and the 
  chooser pops up.




2018-10-02

## 3.7 Implemented simulation mode

- Now should work without pump hardware

- unit will still go through a sampling / emptying sequence with the 
  progress indicator working as usual, the speed of this will depend on
  the set sample volume.

- added tickbox for simulation mode on settings page

- added test mode display above start button since it seems important
  the user knows what will happen when he presses it. 

2018-10-01

## 3.6 - fix RH disabled bug

fix bug where temperature and RH displays are corrupted when water measurement
turned off.


2018-10-01

## 3.5 - static icons for Water, Temperature and Pressure

The layout of the UI been changed in line with recent discussions. 

Settings

have been moved to the settings screen, except for the reporting format
(for now). This has been kept on the home screen mainly for demonstration
purposes and because this allows the real on-screen result to be previewed
in each format while choosing another one.

"Gauge" Icons

We have some icons on the home screen for Pressure, Water and Temperature.
These are "static" at the moment, i.e. they do not change, the values appear
next to them. In a future release they can be animated to show a moving pressure
needle, thermometer bar position etc.

There is also a placeholder icon for "contamination", we could display the result
code there which would allow a graph to be larger so it covers where the result
is now.

Next I will be working on the simulation mode.

NB there are two types of "simulator", both of which are WIP at this point.
There is the included simulator that runs on the PC, this may be useful
for generating screenshots and general discussion. And there is the 
"simulation mode" of the LPA3 itself, activated from the user settings dialog
in LPA-View.


2018-09-27

## 3.4 - Working detailed counts display

Detailed counts now working for all implemented reporting formats.
"Triple tests" show zeros for the 3 stage counts but final totals are
OK. (stages not implemented yet).

The counts table resizes and the size titles change as needed for the
different reporting formats and test types. I.e. it switches between
single and triple test format and between cumulative and differential
counting formats. The counts are always held internally as cumulative
and the differential counts generated on-the-fly as needed. This means
that an existing test result can be viewed in any reporting format.


2018-09-13 

## 3.3 - Added RH, Temperature and Pressure displays to main screen.

Pressure Transducer
-------------------
  - The pressure display activates when a transducer is wired to the PCB.
  - Unlike the other displays it is continuously updated
  - If <2Bar then it displays "<2Bar"
  - Otherwise it displays the pressure in Bar, in real time

RH + Temperature
----------------
  - Real time display of these added to diagnostics screen
  - Setting "Measure Water Content" added to settings screen + lpa-view
  - RH+Temperature displayed on main screen at end of test, if selected above
  - For non-continuous test modes these are blanked once a new test begins
    else they are left on-screen as are the particle count results

Completed "no 4u" option support (tickbox in LPA-View only)

Fixed firmware version numbering - was stuck at 3.0 before 
(in LPA-View remote control)

Added display of firmware revision to diagnostics screen title bar

fix simulator build from TGFX


2018-09-10

## 3.2 - completed display of result class and codes for all existing formats
==========================================================================

(i.e. all except GOST and GJB420)

The display of all formats has been made more uniform and logical. Previously
we have had different implementations for the ICM and LPA2.

I have tried to follow the standards for this where possible.

We have two lines for the contamination reporting. The "Class" line at the top
in a large font. And the "codes" line underneath in a smaller font.

The "class" line shows the overall contamination class of the test, 
according to the set standard. In the case of ISO4406 it shows the
3-part code since there is no concept of an "overall class" in that case. So this
line would show "21/19/15" or "Class 11" etc.

The "codes" line shows the detailed codes (not the counts) for the selected
format. Or is empty for ISO4406. This line might show (00 7 11 00 00) for
example for NAS1638 and all the other NAS based codes.




2018-09-08

## 3.1 Initial release of a LPA3 installer utility
